@@ -1,7 +1,7 @@
 import requests
 import gzip
 import shutil
-import threading
+import multiprocessing
 
 from typing import Literal
 from pathlib import Path
@@ -45,19 +45,22 @@ def wkhtmltopdf_bin(
     bin_path = final_path / final_name
 
     r = requests.get(url, stream=True)
-
-    with threading.Lock():
+    th_id = multiprocessing.current_process()
+    print("========================================== 0 ", th_id)
+    with multiprocessing.Lock():
+        print("========================================== 1 ", th_id)
         with open(gz_path, "wb") as f:
             for chunk in r.iter_content(chunk_size=1024):
                 if chunk:
                     f.write(chunk)
+            print("========================================== 2 ", th_id)
+            with gzip.open(HOME / filename, "rb") as f_in:
+                with open(bin_path, "wb") as f_out:
+                    shutil.copyfileobj(f_in, f_out)
+            print("========================================== 3 ", th_id)
+            gz_path.unlink()
 
-        with gzip.open(gz_path, "rb") as f_in:
-            with open(bin_path, "wb") as f_out:
-                shutil.copyfileobj(f_in, f_out)
-
-        gz_path.unlink()
-
+    print("========================================== 4 ", th_id)
     return str(bin_path)
 
 
